@@ -1,5 +1,7 @@
 from datetime import datetime
 
+import projectal
+
 from projectal.entity import Entity
 from projectal import api
 
@@ -30,4 +32,6 @@ class Location(Entity):
         params.append('until={}'.format(until)) if until else None
         url += '&'.join(params)
 
-        return api.get(url)
+        cals = api.get(url)
+        cals = [projectal.Calendar(c) for c in cals]
+        return cals
