@@ -95,7 +95,7 @@ class BaseLinker(dict):
             else:
                 for to_entity in to_entity_list:
                     # Find it in original list
-                    for i, old in enumerate(from_entity[to_key]):
+                    for i, old in enumerate(from_entity.get(to_key, [])):
                         if old['uuId'] == to_entity['uuId']:
                             if operation == 'update':
                                 from_entity[to_key][i] = to_entity
@@ -109,7 +109,8 @@ class BaseLinker(dict):
 
         # Update the "old" record of the link on the entity to avoid
         # flagging it for changes (link lists are not meant to be user editable).
-        from_entity._Entity__old[to_key] = from_entity[to_key]
+        if to_key in from_entity:
+            from_entity._Entity__old[to_key] = from_entity[to_key]
 
 
 class AccessPolicyLinker(BaseLinker):
